==> node_promo_picker-7.x-1.1.tar.gz: node_promo_picker/node_promo_picker_primary.tpl.php <==
<?php
/**
 * @file
 * Template file for primary promo theme.
 *
 * Available variables:
 * - $teasers: array of teaser objects
 * - $tid: int, taxonomy id
 *
 * Teaser Object
 * - teaser_id - int, unique identifier of the teaser record
 * - title - string, the teaser title
 * - body - string, the treaser body
 * - related_nid - int, related node id for the teaser
 * - uid - int, the user id who created the node
 * - delta - int, the weight order for the teaser
 * - node - object, related node object
 * - images - array, image node objects
 *
 */
$teasers = $variables['teasers'];
$tid = $variables['tid'];
?>
<?php if (!empty($teasers)): ?>
  <div class="featuredArticles">
    <div class="featuredArticlesWrapper">
    <?php foreach ($teasers as $cnt => $t): ?>
      <div class="promoItemWrapper">
        <div class="featured-articles-intro">
          <h3>
            <?php print l(drupal_substr($t->title, 0, 50), 'node/' . $t->node->nid, array('attributes' => array('class' => 'linkSource'))); ?>
          </h3>
          <?php if (user_access('administer nodes')): ?>
            <?php print l(t('edit teaser'), 'admin/structure/promo_picker/edit-teaser/' . $t->teaser_id, array('query' => array('return_to' => $_GET['q']))); ?>
            <?php print l(t('edit node'), 'node/' . $t->node->nid . '/edit', array('query' => array('destination' => $_GET['q']))); ?>
          <?php endif; ?>
          <p><?php print drupal_substr($t->body, 0, 160); ?>&nbsp;<?php print l(t('Read more'), 'node/' . $t->node->nid, array('attributes' => array('class' => 'teaserReadMore pngFix'))); ?></p>
        </div>
        <?php if (!empty($t->images)): ?>
          <span class="countPromoImages">
          <?php foreach ($t->images as $images): ?>
            <?php if (!empty($images->field_image[0])): ?>
              <span class="promo_image_wrapper">
                <img src="/<?php print $image->field_image[0]['filepath']; ?>" alt="" class="landing-page-intro-image triggerLink" />
              </span>
            <?php endif; ?>
          <?php endforeach; ?>
          </span>
        <?php endif; ?>
      </div>
    <?php endforeach; ?>
    </div>
  </div>
<?php endif; ?>

==> node_promo_picker-7.x-1.8.tar.gz: node_promo_picker/node_promo_picker_primary.tpl.php <==
<?php
/**
 * @file
 * Template file for primary promo theme.
 *
 * Available variables:
 * - $teasers: array of teaser objects
 * - $tid: int, taxonomy id
 *
 * Teaser Object
 * - teaser_id - int, unique identifier of the teaser record
 * - title - string, the teaser title
 * - body - string, the treaser body
 * - related_nid - int, related node id for the teaser
 * - uid - int, the user id who created the node
 * - delta - int, the weight order for the teaser
 * - node - object, related node object
 * - images - array, image node objects
 *
 */
$teasers = $variables['teasers'];
$tid = $variables['tid'];
?>
<?php if (!empty($teasers)): ?>
  <div class="featuredArticles">
    <div class="featuredArticlesWrapper">
    <?php foreach ($teasers as $cnt => $t): ?>
      <div class="promoItemWrapper">
        <div class="featured-articles-intro">
          <h3>
            <?php print l(drupal_substr($t->title, 0, 50), 'node/' . $t->node->nid); ?>
          </h3>
          <?php if (user_access('administer nodes')): ?>
            <?php print l(t('edit teaser'), 'admin/structure/promo_picker/edit-teaser/' . $t->teaser_id, array('query' => array('return_to' => $_GET['q']))); ?>
            <?php print l(t('edit node'), 'node/' . $t->node->nid . '/edit', array('query' => array('destination' => $_GET['q']))); ?>
          <?php endif; ?>
          <p><?php print drupal_substr($t->body, 0, 160); ?>&nbsp;<?php print l(t('Read more'), 'node/' . $t->node->nid); ?></p>
        </div>
        <?php if (!empty($t->images)): ?>
          <span class="countPromoImages">
          <?php foreach ($t->images as $images): ?>
            <?php if (!empty($images->field_image[0])): ?>
              <span class="promo_image_wrapper">
                <img src="/<?php print $image->field_image[0]['filepath']; ?>" alt="" class="landing-page-intro-image triggerLink" />
              </span>
            <?php endif; ?>
          <?php endforeach; ?>
          </span>
        <?php endif; ?>
      </div>
    <?php endforeach; ?>
    </div>
  </div>
<?php endif; ?>
